@@ -569,3 +569,17 @@ class CommandlineTest(UnitTestCase):
             with self.assertRaises(CommandLineError) as cm:
                 cline = shlex.split(f"{cmd} file://source_url foo/bar --dry-run")
                 cli_main.process_command_line(cline)
+
+        # Issue 795 - invalid option error using --gpg-options - unbound
+        cline = shlex.split(
+            "backup --gpg-options '--compress-algo=bzip2 --bzip2-compress-level=9' foo/bar file://target_url"
+        )
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.gpg_options, "--compress-algo=bzip2 --bzip2-compress-level=9")
+
+        # Issue 795 - invalid option error using --gpg-options - bound
+        cline = shlex.split(
+            "backup --gpg-options='--compress-algo=bzip2 --bzip2-compress-level=9' foo/bar file://target_url"
+        )
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.gpg_options, "--compress-algo=bzip2 --bzip2-compress-level=9")
